Teste LCD I2C 20X4

Dependencies:   TextLCD mbed

Revision:
2:74d01fef184a
Parent:
1:13cafaed8cff
Child:
3:e87183be497b
--- a/main.cpp	Tue May 10 13:27:48 2022 +0000
+++ b/main.cpp	Wed May 11 10:42:37 2022 +0000
@@ -19,8 +19,8 @@
 //TextLCD lcd(p15, p16, p17, p18, p19, p20);  // RS, E, D4-D7, LCDType=LCD16x2, BL=NC, E2=NC, LCDTCtrl=HD44780
  
 //I2C Portexpander PCF8574
-TextLCD_I2C lcd(&i2c_lcd, 0x3F, TextLCD::LCD20x4); // I2C bus, PCF8574 Slaveaddress, LCD Type Original = 0x42, Usando I2C scanner = 0x3F
-//TextLCD_I2C lcd(&i2c_lcd, 0x42, TextLCD::LCD16x2, TextLCD::WS0010); // I2C bus, PCF8574 addr, LCD Type, Ctrl Type
+TextLCD_I2C lcd(&i2c_lcd, 0x7e, TextLCD::LCD20x4); // I2C bus, PCF8574 Slaveaddress, LCD Type Original = 0x42, Usando I2C scanner = 0x3F
+//TextLCD_I2C lcd(&i2c_lcd, 0x7e, TextLCD::LCD16x2, TextLCD::WS0010); // I2C bus, PCF8574 addr, LCD Type, Ctrl Type
  
 //I2C Portexpander MCP23008
 //TextLCD_I2C lcd(&i2c_lcd, MCP23008_SA0, TextLCD::LCD16x3G, TextLCD::ST7036_3V3); // I2C bus, MCP23008 Slaveaddress, LCD Type, LCDTCtrl=ST7036
@@ -66,7 +66,8 @@
     
 // Show cursor as blinking character
     lcd.setCursor(TextLCD::CurOff_BlkOn);
-
+    lcd.setBacklight(TextLCD::LightOn);
+    
 // Set and show user defined characters. A maximum of 8 UDCs are supported by the HD44780.
 // They are defined by a 5x7 bitpattern. 
 /*